@@ -69,7 +69,7 @@ namespace Breeze
     }
 
     //_________________________________________________________
-    void ConfigWidget::load( void )
+    void ConfigWidget::load()
     {
 
         // create internal settings and load from rc files
@@ -103,7 +103,7 @@ namespace Breeze
     }
 
     //_________________________________________________________
-    void ConfigWidget::save( void )
+    void ConfigWidget::save()
     {
 
         // create internal settings and load from rc files
@@ -151,7 +151,7 @@ namespace Breeze
     }
 
     //_________________________________________________________
-    void ConfigWidget::defaults( void )
+    void ConfigWidget::defaults()
     {
 
         // create internal settings and load from rc files
@@ -175,7 +175,7 @@ namespace Breeze
     }
 
     //_______________________________________________
-    void ConfigWidget::updateChanged( void )
+    void ConfigWidget::updateChanged()
     {
 
         // check configuration
